# PrettyTables.jl

```@meta
CurrentModule = PrettyTables
```

```@setup index
using PrettyTables
```

The Julia package [PrettyTables.jl](https://github.com/ronisbr/PrettyTables.jl) has the
purpose to print data in matrices in a human-readable format. It was inspired in the
functionality provided by [ASCII Table Generator](https://ozh.github.io/ascii-tables/).

```@repl index
using PrettyTables

t = 0:1:20

data = hcat(t, ones(length(t) ), t, 0.5.*t.^2);

header = (
    ["Time", "Acceleration", "Velocity", "Distance"],
    [ "[s]",     "[m / s²]",  "[m / s]",      "[m]"]
)

hl_p = Highlighter(
    (data, i, j) -> (j == 4) && (data[i, j] > 9),
    crayon"blue bold"
);

hl_v = Highlighter(
    (data, i, j) -> (j == 3) && (data[i, j] > 9),
    crayon"red bold"
);

hl_10 = Highlighter(
    (data, i, j) -> (i == 10),
    crayon"fg:white bold bg:dark_gray"
);
```

```julia
julia> pretty_table(
    data;
    formatters    = ft_printf("%5.2f", 2:4),
    header        = header,
    header_crayon = crayon"yellow bold",
    highlighters  = (hl_10, hl_p, hl_v),
    tf            = tf_unicode_rounded
)
```

```@setup index
str = pretty_table(
    String,
    data;
    color         = true,
    formatters    = ft_printf("%5.2f", 2:4),
    header        = header,
    header_crayon = crayon"yellow bold",
    highlighters  = (hl_10, hl_p, hl_v),
    tf            = tf_unicode_rounded
)

write("tmp", str)

run(`ansitoimg --width 60 --title "PrettyTables.jl (generated by AnsiToImg)" tmp welcome_figure.svg`)

run(`rm tmp`)
```

![Welcome figure](./welcome_figure.svg)

## Installation

```julia-repl
julia> using Pkg
julia> Pkg.add("PrettyTables")
```

## Manual outline

```@contents
Pages = [
    "man/usage.md"
    "man/text_backend.md"
    "man/html_backend.md"
    "man/latex_backend.md"
    "man/markdown_backend.md"
    "man/alignment.md"
    "man/formatters.md"
    "man/text_examples.md"
    "man/html_examples.md"
    "lib/library.md"
]
Depth = 2
```
